"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.App = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const ink_1 = require("ink");
const ink_spinner_1 = tslib_1.__importDefault(require("ink-spinner"));
const Error_1 = require("./Error");
async function deletePipelinesForProject(projectId, props, reportProgress) {
    const { startDate, days, listPipelines, filterPipelinesByDate, deletePipeline } = props;
    const pipelines = await listPipelines(projectId);
    const oldPipelines = filterPipelinesByDate({ startDate, olderThanDays: days, pipelines });
    return oldPipelines.map((pipeline) => {
        return props.deleteQueue.add(() => {
            reportProgress(`Deleting pipeline with id ${pipeline.id} for project ${projectId}`);
            return deletePipeline(projectId, pipeline);
        });
    });
}
async function deletePipelines(props, reportProgress) {
    const { deleteQueue } = props;
    try {
        const projectDeletions = props.projectIds.map((projectId) => {
            return deletePipelinesForProject(projectId, props, reportProgress);
        });
        const deleteTasks = await Promise.all(projectDeletions);
        const { deleteQueue } = props;
        reportProgress(`${deleteQueue.size} pipelines found`);
        deleteQueue.start();
        await Promise.all(deleteTasks.flat());
        return deleteQueue.onIdle();
    }
    catch (error) {
        deleteQueue.clear();
        throw error;
    }
}
const App = (props) => {
    const [deleteProgress, setDeleteProgress] = (0, react_1.useState)(['']);
    const [isDone, setDone] = (0, react_1.useState)(false);
    const [deletePipelinesError, setDeletePipelinesError] = (0, react_1.useState)();
    (0, react_1.useEffect)(() => {
        deletePipelines(props, (text) => {
            setDeleteProgress((currentDeleteProgress) => [...currentDeleteProgress, text]);
        })
            .then(() => {
            setDone(true);
        })
            .catch(setDeletePipelinesError);
    }, [props]);
    if (deletePipelinesError !== undefined) {
        const message = props.showStackTraces ? deletePipelinesError.stack : deletePipelinesError.message;
        return react_1.default.createElement(Error_1.Error, { exit: props.exit },
            "There was an error while deleting the pipelines: ",
            message);
    }
    return (react_1.default.createElement(react_1.Fragment, null,
        react_1.default.createElement(ink_1.Static, { items: deleteProgress }, (text) => react_1.default.createElement(ink_1.Text, { key: text }, text)),
        react_1.default.createElement(ink_1.Text, null,
            !isDone && react_1.default.createElement(ink_spinner_1.default, null),
            isDone && react_1.default.createElement(ink_1.Text, { color: "green" }, "Pipelines deleted"))));
};
exports.App = App;
//# sourceMappingURL=App.js.map