"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mergeCliArgumentsWithConfig = exports.loadConfig = void 0;
const tslib_1 = require("tslib");
const true_myth_1 = require("true-myth");
const is_1 = tslib_1.__importDefault(require("@sindresorhus/is"));
const zod_1 = require("zod");
const baseConfigSchema = zod_1.z.object({
    gitlabUrl: zod_1.z.string().url(),
    accessToken: zod_1.z.string(),
    days: zod_1.z.number(),
    trace: zod_1.z.boolean(),
});
const configSchema = baseConfigSchema.extend({
    projectIds: zod_1.z.array(zod_1.z.number().positive()).nonempty(),
});
const configInputSchema = baseConfigSchema.extend({ projectId: zod_1.z.string() });
const partialConfigInputSchema = configInputSchema.strict().partial();
async function loadConfig(filePath, explorer) {
    try {
        const loaded = await explorer.load(filePath);
        if (loaded === null || loaded === void 0 ? void 0 : loaded.isEmpty) {
            return true_myth_1.Result.ok({});
        }
        const parsedConfig = partialConfigInputSchema.safeParse(loaded === null || loaded === void 0 ? void 0 : loaded.config);
        if (parsedConfig.success) {
            return true_myth_1.Result.ok(parsedConfig.data);
        }
        return true_myth_1.Result.err('config-invalid');
    }
    catch (error) {
        if (is_1.default.error(error)) {
            return true_myth_1.Result.ok({});
        }
        return true_myth_1.Result.err('unknown');
    }
}
exports.loadConfig = loadConfig;
function convertToNumber(value) {
    return parseInt(value, 10);
}
function commaSeparatedStringToNumberArray(commaSeparatedString) {
    return commaSeparatedString.split(',').map(convertToNumber);
}
function mergeCliArgumentsWithConfig(cliArguments, config) {
    var _a, _b, _c, _d, _e;
    const configInput = configInputSchema.safeParse({
        gitlabUrl: (_a = cliArguments === null || cliArguments === void 0 ? void 0 : cliArguments.gitlabUrl) !== null && _a !== void 0 ? _a : config === null || config === void 0 ? void 0 : config.gitlabUrl,
        projectId: (_b = cliArguments === null || cliArguments === void 0 ? void 0 : cliArguments.projectId) !== null && _b !== void 0 ? _b : config === null || config === void 0 ? void 0 : config.projectId,
        accessToken: (_c = cliArguments === null || cliArguments === void 0 ? void 0 : cliArguments.accessToken) !== null && _c !== void 0 ? _c : config === null || config === void 0 ? void 0 : config.accessToken,
        days: (_d = cliArguments === null || cliArguments === void 0 ? void 0 : cliArguments.days) !== null && _d !== void 0 ? _d : config === null || config === void 0 ? void 0 : config.days,
        trace: (_e = cliArguments === null || cliArguments === void 0 ? void 0 : cliArguments.trace) !== null && _e !== void 0 ? _e : config === null || config === void 0 ? void 0 : config.trace,
    });
    if (!configInput.success) {
        return true_myth_1.Result.err('config-invalid');
    }
    const parsedConfigSchema = configSchema.safeParse({
        gitlabUrl: configInput.data.gitlabUrl,
        projectIds: commaSeparatedStringToNumberArray(configInput.data.projectId),
        accessToken: configInput.data.accessToken,
        days: configInput.data.days,
        trace: configInput.data.trace,
    });
    if (!parsedConfigSchema.success) {
        return true_myth_1.Result.err('config-invalid');
    }
    return true_myth_1.Result.ok(parsedConfigSchema.data);
}
exports.mergeCliArgumentsWithConfig = mergeCliArgumentsWithConfig;
//# sourceMappingURL=config.js.map