"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.filterPipelinesByDate = exports.deletePipeline = exports.listPipelines = void 0;
const tslib_1 = require("tslib");
const urlcat_1 = tslib_1.__importDefault(require("urlcat"));
const date_fns_1 = require("date-fns");
function listPipelines({ getRequest, gitlabUrl, accessToken }) {
    return (projectId) => {
        const url = (0, urlcat_1.default)(gitlabUrl, '/api/v4/projects/:id/pipelines', { id: projectId, per_page: 100 });
        return getRequest(url, accessToken);
    };
}
exports.listPipelines = listPipelines;
function deletePipeline({ deleteRequest, gitlabUrl, accessToken, }) {
    return async (projectId, pipeline) => {
        const url = (0, urlcat_1.default)(gitlabUrl, '/api/v4/projects/:id/pipelines/:pipeline_id', {
            id: projectId,
            pipeline_id: pipeline.id,
        });
        await deleteRequest(url, accessToken);
    };
}
exports.deletePipeline = deletePipeline;
function isOlderThanDays(startDate, pipelineDate, days) {
    return (0, date_fns_1.differenceInDays)(startDate, pipelineDate) > days;
}
const filterPipelinesByDate = ({ pipelines, startDate, olderThanDays }) => {
    return pipelines.filter((pipeline) => {
        const pipelineDate = (0, date_fns_1.parseISO)(pipeline.updated_at);
        return isOlderThanDays(startDate, pipelineDate, olderThanDays);
    });
};
exports.filterPipelinesByDate = filterPipelinesByDate;
//# sourceMappingURL=gitlab.js.map